==> owfs-2.7p13.tar.gz: owfs-2.7p13/module/owlib/src/include/ow_dirblob.h <==
/*
$Id: ow_dirblob.h,v 1.4 2007/02/18 06:51:34 alfille Exp $
    OW -- One-Wire filesystem
    version 0.4 7/2/2003

    Function naming scheme:
    OW -- Generic call to interaface
    LI -- LINK commands
    L1 -- 2480B commands
    FS -- filesystem commands
    UT -- utility functions

    Written 2003 Paul H Alfille
        Fuse code based on "fusexmp" {GPL} by Miklos Szeredi, mszeredi@inf.bme.hu
        Serial code based on "xt" {GPL} by David Querbach, www.realtime.bc.ca
        in turn based on "miniterm" by Sven Goldt, goldt@math.tu.berlin.de
    GPL license
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    Other portions based on Dallas Semiconductor Public Domain Kit,
    ---------------------------------------------------------------------------
    Copyright (C) 2000 Dallas Semiconductor Corporation, All Rights Reserved.
        Permission is hereby granted, free of charge, to any person obtaining a
        copy of this software and associated documentation files (the "Software"),
        to deal in the Software without restriction, including without limitation
        the rights to use, copy, modify, merge, publish, distribute, sublicense,
        and/or sell copies of the Software, and to permit persons to whom the
        Software is furnished to do so, subject to the following conditions:
        The above copyright notice and this permission notice shall be included
        in all copies or substantial portions of the Software.
    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
    OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
    MERCHANTABILITY,  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
    IN NO EVENT SHALL DALLAS SEMICONDUCTOR BE LIABLE FOR ANY CLAIM, DAMAGES
    OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
    ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
    OTHER DEALINGS IN THE SOFTWARE.
        Except as contained in this notice, the name of Dallas Semiconductor
        shall not be used except as stated in the Dallas Semiconductor
        Branding Policy.
    ---------------------------------------------------------------------------
    Implementation:
    2006 dirblob
*/

#ifndef OW_DIRBLOB_H			/* tedious wrapper */
#define OW_DIRBLOB_H

struct dirblob {
	int troubled;
	int allocated;
	int devices;
	BYTE *snlist;
};

void DirblobClear(struct dirblob *db);
void DirblobInit(struct dirblob *db);
int DirblobPure(struct dirblob *db);
int DirblobAdd(BYTE * sn, struct dirblob *db);
int DirblobGet(int dev, BYTE * sn, const struct dirblob *db);
int DirblobSearch(BYTE * sn, const struct dirblob *db);

#endif							/* OW_DIRBLOB_H */

==> owfs_3.1p0.orig.tar.gz: owfs-3.1p0/module/owlib/src/include/ow_dirblob.h <==
/*
$Id$
    OW -- One-Wire filesystem
    version 0.4 7/2/2003

    Function naming scheme:
    OW -- Generic call to interaface
    LI -- LINK commands
    L1 -- 2480B commands
    FS -- filesystem commands
    UT -- utility functions

    Written 2003 Paul H Alfille
        Fuse code based on "fusexmp" {GPL} by Miklos Szeredi, mszeredi@inf.bme.hu
        Serial code based on "xt" {GPL} by David Querbach, www.realtime.bc.ca
        in turn based on "miniterm" by Sven Goldt, goldt@math.tu.berlin.de
    GPL license
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    ---------------------------------------------------------------------------
    Implementation:
    2006 dirblob
*/

#ifndef OW_DIRBLOB_H			/* tedious wrapper */
#define OW_DIRBLOB_H

struct dirblob {
	int troubled;
	int allocated;
	int devices;
	BYTE *snlist;
};

void DirblobClear(struct dirblob *db);
void DirblobInit(struct dirblob *db);
int DirblobPure(const struct dirblob *db);
void DirblobPoison(struct dirblob *db);
int DirblobElements(const struct dirblob *db);
int DirblobAdd(const BYTE * sn, struct dirblob *db);
int DirblobGet(int dev, BYTE * sn, const struct dirblob *db);
int DirblobSearch(BYTE * sn, const struct dirblob *db);
int DirblobRecreate( BYTE * snlist, int size, struct dirblob *db);

#endif							/* OW_DIRBLOB_H */
